@@ -1156,6 +1156,13 @@ class Project(BaseProject):
         Returns:
 
             tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``)
+        
+        Example:
+
+            .. image:: /home/benchay/codes/astrape_pkg/tutorial/results/DIGITS-debug/results/MLP-batch_size256-bnTrue-dropout_p0-l1_strength0-lr0d0001-n_hidden_units10-n_layers2-optimizer_typeadam-weight_decay0.png
+            :width: 400
+            :alt: Plot example
+            
         """
         performances, metadata = self.search_with_model_type_hparams(
             val_metric=val_metric, model_type=model_type, **hparams
@@ -1226,9 +1233,18 @@ class Project(BaseProject):
         Returns:
 
             tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``)
-        """
-    # (validation performances, list of model metadata)
         
+        Example:
+
+            .. image:: /home/benchay/codes/astrape_pkg/tutorial/results/DIGITS-debug/results/'Performances For All Models.png'
+            :width: 400
+            :alt: Performance plot of all models
+
+            .. image:: /home/benchay/codes/astrape_pkg/tutorial/results/DIGITS-debug/results/'Performances For All Models_boxplot.png'
+            :width: 400
+            :alt: Performance plot (box plot) of all models
+        
+        """
         metadata_list, performances_list = self.search_all_models(val_metric)
         random_state_dir_list = self.get_available_random_states()
         random_number_list = []
